@@ -1,7 +1,7 @@
 package Minion::Backend::Mango;
 use Mojo::Base 'Minion::Backend';
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 use Mango;
 use Mango::BSON qw(bson_oid bson_time bson_doc);
@@ -14,6 +14,9 @@ has notifications => sub { $_[0]->mango->db->collection($_[0]->prefix . '.notifi
 has prefix        => 'minion';
 has workers       => sub { $_[0]->mango->db->collection($_[0]->prefix . '.workers') };
 
+sub broadcast {}
+sub receive { [] }
+
 sub dequeue {
   my ($self, $wid, $wait, $options) = @_;
 
